;-------------------------------------------------------------------------------
; ralfs_asm.asm
;
; Testprogramm zur Demo fuer den Assembler
;
; Ein paar Dummys zur Anschauung
;
; Prozessor: SAB80535 (NMOS)
;
; Wilhelm Ferkes
;
;-------------------------------------------------------------------------------

  .title Programm_Test_fuer_80535-Board
  .sbttl Version_fuer_SAB80535
  .module Testprogramm

;-----------------------------------------------------------

; Include-Datei mit Registern und Symbolen

  .include "sab80c515.inc"        ; SAB80C515-spezifische SFR, z.B. EAL hier.

;-----------------------------------------------------------

;-----------------------------------------------------------
; Globale Definitionen
;-----------------------------------------------------------

OFF   = 0
ON    = 1
FALSE = 0
TRUE  = 1

FREQUENCY = 6000000                     ; Quarzfrequenz

;-----------------------------------------------------------

BASE      = 0x1000              ; Linkadresse im RAM

;-----------------------------------------------------------

; Berechnung Interruptvektoren:

INT_OFFSET_1 = 8                ; Vektorabstaende
INT_OFFSET_2 = 3                ; Versatz zu Null

IE0_VEKTOR  = IE0_VECTOR  * INT_OFFSET_1 + INT_OFFSET_2
TF0_VEKTOR  = TF0_VECTOR  * INT_OFFSET_1 + INT_OFFSET_2
IE1_VEKTOR  = IE1_VECTOR  * INT_OFFSET_1 + INT_OFFSET_2
TF1_VEKTOR  = TF1_VECTOR  * INT_OFFSET_1 + INT_OFFSET_2
SI0_VEKTOR  = SI0_VECTOR  * INT_OFFSET_1 + INT_OFFSET_2
TF2_VEKTOR  = TF2_VECTOR  * INT_OFFSET_1 + INT_OFFSET_2
IADC_VEKTOR = IADC_VECTOR * INT_OFFSET_1 + INT_OFFSET_2
IEX2_VEKTOR = IEX2_VECTOR * INT_OFFSET_1 + INT_OFFSET_2
IEX3_VEKTOR = IEX3_VECTOR * INT_OFFSET_1 + INT_OFFSET_2
IEX4_VEKTOR = IEX4_VECTOR * INT_OFFSET_1 + INT_OFFSET_2
IEX5_VEKTOR = IEX5_VECTOR * INT_OFFSET_1 + INT_OFFSET_2
IEX6_VEKTOR = IEX6_VECTOR * INT_OFFSET_1 + INT_OFFSET_2

;-----------------------------------------------------------

; Speicherreservierung:

;-----------------------------------------------------------

  .area BDATABASE (REL, CON, BIT)

;-----------------------------------------------------------

Testbit1:           .ds 1  ; 1 Bit Speicherreservierung Flag
Testbit2:           .ds 1  ; 1 Byte Speicherreservierung Flag
Testbit3:           .ds 1  ; 1 Byte Speicherreservierung Flag
MILLISEKUNDE_DA:    .ds 1  ; Flag Post vom Timer
.blkb                0x04  ; reservierter Space im Byte

Testbit4:           .ds 1  ; 1 Byte Speicherreservierung Flag
Testbit5:           .ds 1  ; 1 Byte Speicherreservierung Flag
Testbit6:           .ds 1  ; 1 Byte Speicherreservierung Flag
.blkb                0x05  ; reservierter Space im Byte

;-----------------------------------------------------------

  .area IDATABASE1 (REL, CON, DATA)

;-----------------------------------------------------------

Rbase1     =   #.       ; niedrigstes RAM-Byte dieses Segmentes

TESTBYTEKETTENSIZE = 16
TESTBYTEKETTE1: .ds  TESTBYTEKETTENSIZE ; 16 Bytes im internen RAM
TESTBYTEKETTE2: .ds  TESTBYTEKETTENSIZE ; 16 Bytes im internen RAM

KEY_BUF:   .ds  1       ; Speicherstelle Tastaturcode
COUNTER:   .ds  1       ; Universalzaehler
ACCSAV:    .ds  1       ; Accu-Sicherungsbyte
LCDSAV:    .ds  1       ; LCD-Routinen Sicherungsbyte

Rtop1  =   #. - 1       ; Adresse des hoechsten RAM-Bytes hier

;-----------------------------------------------------------

  .area IDATABASE2 (REL, CON, DATA)

;-----------------------------------------------------------

Rbase2     =   #.       ; niedrigstes RAM-Byte dieses Segmentes

TESTBYTE1: .ds  1       ; 1 Byte Speicherreservierung Dummy zur Demo
TESTBYTE2: .ds  5       ; 5 Byte Speicherreservierung Dummy zur Demo

Rtop2  =   #. - 1       ; Adresse des hoechsten RAM-Bytes hier
                        ; wird fuer den Stack benoetigt

STACK  =   Rtop2        ; Stackpointer wird auf letztes Byte gesetzt

;-----------------------------------------------------------

  .area CODEBASE (CODE, ABS, OVR)

;-----------------------------------------------------------

reset:  LJMP    START   ; Startadresse 0000H

;-----------------------------------------------------------

intvects:       ; alle Interrupts werden auf XRAM umgelenkt:

  .org  BASE+IE0_VEKTOR
        reti
  .org  BASE+TF0_VEKTOR
        ljmp    TF0_ISR
  .org  BASE+IE1_VEKTOR
        reti
  .org  BASE+TF1_VEKTOR
        reti
  .org  BASE+SI0_VEKTOR
        reti
  .org  BASE+TF2_VEKTOR
        reti
  .org  BASE+IADC_VEKTOR
        reti
  .org  BASE+IEX2_VEKTOR
        reti
  .org  BASE+IEX3_VEKTOR
        reti
  .org  BASE+IEX4_VEKTOR
        reti
  .org  BASE+IEX5_VEKTOR
        reti
  .org  BASE+IEX6_VEKTOR
        reti

;-----------------------------------------------------------

  .area CODE1 (CODE, REL, CON)

;-----------------------------------------------------------

; Programmstart hier:

START:  CLR     EAL             ; alle Interrupts sperren
        MOV     PSW,#0          ; RESET Registerbank
        MOV     SP,#STACK       ; oberhalb des verwendeten RAM

        MOV     R0,#0x1F        ; groesste Adresse
        MOV     R1,#0x18        ; Anzahl Bytes
        ACALL   CLR_RAM         ; RB1, RB2 und RB3 loeschen

        MOV     R0,#0x2F        ; groesste Adresse
        MOV     R1,#0x10        ; Anzahl Bytes
        ACALL   CLR_RAM         ; Flag-Bereich loeschen

        MOV     R0,#Rtop1       ; groesste Adresse
        MOV     R1,#(Rtop1-Rbase1+1); Anzahl Bytes
        ACALL   CLR_RAM         ; RAM-Bereich loeschen

        MOV     R0,#Rtop2       ; groesste Adresse
        MOV     R1,#(Rtop2-Rbase2+1); Anzahl Bytes
        ACALL   CLR_RAM         ; RAM-Bereich loeschen

        ANL     IP1,#0B11111101 ; setze Timer0-Interrupt
        ORL     IP0,#0B00000010 ; auf Prioritaet 1

        MOV     TMOD,#0x01      ; Timer 0 Modus 1 16-bit-Timer
        SETB    ET0             ; Interruptfreigabe ET0 = Timer 0

        SETB    TR0             ; jetzt Timer starten
        SETB    EAL             ; und Interrupts frei geben

        LJMP    MAINLOOP

;-----------------------------------------------------------

  .area CODE2 (CODE, REL, CON)

;-----------------------------------------------------------

; Ralf: Hier gibt es kein sinnvolles Programm, das ist nur eine Demo
; fuer den Assembler in den SDCC-Tools.

; Um zu sehen, wie der Assembler den Speicher belegt, muss man sich die
; erzeugten Files anschauen: *.lkr, *.lst, *.map, *.rel, *.rst, *.s37, *.sym.

; Nicht immer gibt es Fehlermeldungen, z.B. wenn man mit den internen RAM-
; Bytes nicht auf passt, und die sich ueberlappen. Man muss sich die gerade
; genannten Dateien genau anschauen.

; Das absolute Listing ist in *.rst, das Hex-File in *.s37.

MAINLOOP:
        CPL     Testbit1
        CPL     Testbit3
        MOV     C, Testbit1
        ANL     C, Testbit3
        MOV     ACC.7, C
        MOV     COUNTER, A
        JNB     MILLISEKUNDE_DA, MAINLOOP_10
        CLR     MILLISEKUNDE_DA
; uebrigens, der Timer laeuft schon praezise, da sollte hier schon was
; machbar sein.
        NOP                     ; hier kann man was machen, wenn vom Timer
        NOP                     ; eine Millisekunde um ist
MAINLOOP_10:
        MOV     R7, A           ; ein paar Dummys
        MOV     A, R7
        MOV     R7, A
        MOV     A, R7
        MOV     R7, A
        MOV     A, R7
        MOV     R7, A
        MOV     A, R7
        MOV     R7, A
        MOV     A, R7
        NOP
        NOP
        NOP
        NOP
        AJMP    MAINLOOP        ; Endlosschleife

;-----------------------------------------------------------

CLR_RAM:MOV     @R0,#0          ; Loeschschleife
        DEC     R0
        DJNZ    R1,CLR_RAM
        RET

;-----------------------------------------------------------

  .area CODE3 (CODE, REL, CON)

;-----------------------------------------------------------

; Interrupt-Service-Routine Timer 0 mit Prioritaet 1:

; Der Timer durchlaeuft diesen Interrupt alle 1/1000 Sekunde.

T0_RELOAD = 0x10000 - ((FREQUENCY / 1000) / 12 - 7)

TF0_ISR:
        PUSH    PSW               ; wichtige Register retten
        PUSH    ACC
        SETB    RS0               ; RB1
        CLR     RS1               ; RB1

; Timer-Reload:

        CLR     EAL               ; Nachladesequenz darf nie gestoert werden
        CLR     TR0
        MOV     A, #((T0_RELOAD >> 0) & 0xFF)
        ADD     A, TL0
        MOV     TL0, A
        MOV     A, #((T0_RELOAD >> 8) & 0xFF)
        ADDC    A, TH0
        MOV     TH0, A
        SETB    TR0
        SETB    EAL

        SETB    MILLISEKUNDE_DA   ; Signal fuer das Hauptprogramm

TF0_ISR_ENDE:
        POP     ACC
        POP     PSW
        RETI

;-----------------------------------------------------------

; End of File
