;-------------------------------------------------------------------------------
;  Register für SIEMENS/INFINEON SAB 80515, 80C515 und 50C515A
;  Zum Einbinden für Assemblercode
;
;  Der AS-Assembler sucht vor den eigenen vordefinierten Symbolen
;  zuerst hier im Include-File!!! Es gibt keinen Konflikt, er übergeht
;  die eigenen Definitionen. Deshalb: Hier sorgfältig arbeiten!!!
;
;  Wilhelm Ferkes fuer Ralf
;-------------------------------------------------------------------------------

; BYTE adressierbare Register
P0      = 0x80          ;
SP      = 0x81          ;
DPL     = 0x82          ;
DPH     = 0x83          ;
WDTREL  = 0x86          ; Watchdog-Timer Reload-Register
PCON    = 0x87          ;
TCON    = 0x88          ;
TMOD    = 0x89          ;
TL0     = 0x8A          ;
TL1     = 0x8B          ;
TH0     = 0x8C          ;
TH1     = 0x8D          ;

P1      = 0x90          ;
XPAGE   = 0x91          ; Adressregister für XRAM
SCON    = 0x98          ;
SBUF    = 0x99          ;

P2      = 0xA0          ;
IE      = 0xA8          ;
IEN0    = 0xA8          ; Interrupt Freigaberegister 0
IP0     = 0xA9          ; Interrupt Prioritätsregister 0
SRELL   = 0xAA          ; Reload-Register Low serielle Schnittstelle

P3      = 0xB0          ;
IEN1    = 0xB8          ; Interrupt Freigaberegister 1
IP1     = 0xB9          ; Interrupt Prioritätsregister 1
SRELH   = 0xBA          ; Reload-Register High serielle Schnittstelle

IRCON   = 0xC0          ; Interrupt Request Register
CCEN    = 0xC1          ; CCU Freigaberegister
CCL1    = 0xC2          ; Compare-/Capture-Register 1, Low Byte
CCH1    = 0xC3          ; Compare-/Capture-Register 1, High Byte
CCL2    = 0xC4          ; Compare-/Capture-Register 2, Low Byte
CCH2    = 0xC5          ; Compare-/Capture-Register 2, High Byte
CCL3    = 0xC6          ; Compare-/Capture-Register 3, Low Byte
CCH3    = 0xC7          ; Compare-/Capture-Register 3, High Byte
T2CON   = 0xC8          ;
CC4EN   = 0xC9          ; Compare-/Capture 4 Freigaberegister
CRCL    = 0xCA          ; Compare/Reload/Capture-Register, Low Byte
CRCH    = 0xCB          ; Compare/Reload/Capture-Register, High Byte
TL2     = 0xCC          ;
TH2     = 0xCD          ;

PSW     = 0xD0          ;
ADCON   = 0xD8          ; AD-Wandler Steuerregister
ADCON0  = 0xD8          ; AD-Wandler Steuerregister 0
ADDAT   = 0xD9          ; AD-Wandler Ergebnisregister
ADDATH  = 0xD9          ; AD-Wandler Ergebnisregister High Byte
DAPR    = 0xDA          ; DA-Wandler Steuerregister für programmierbare Referenzspannungen
ADDATL  = 0xDA          ; AD-Wandler Ergebnisregister Low Byte
P6      = 0xDB          ; Port 6
ADCON1  = 0xDC          ; AD-Wandler Steuerregister 1

ACC     = 0xE0          ;
A       = 0xE0          ;
P4      = 0xE8          ; Port 4

BCC     = 0xF0          ; Ersatzbezeichnung für Register B
B       = 0xF0          ;
P5      = 0xF8          ; Port 5

; BIT addressable registers
; P0
P0.0    = 0x80          ;
P0.1    = 0x81          ;
P0.2    = 0x82          ;
P0.3    = 0x83          ;
P0.4    = 0x84          ;
P0.5    = 0x85          ;
P0.6    = 0x86          ;
P0.7    = 0x87          ;

; TCON
IT0     = 0x88          ;
IE0     = 0x89          ;
IT1     = 0x8A          ;
IE1     = 0x8B          ;
TR0     = 0x8C          ;
TF0     = 0x8D          ;
TR1     = 0x8E          ;
TF1     = 0x8F          ;

; P1
P1.0    = 0x90          ;
P1.1    = 0x91          ;
P1.2    = 0x92          ;
P1.3    = 0x93          ;
P1.4    = 0x94          ;
P1.5    = 0x95          ;
P1.6    = 0x96          ;
P1.7    = 0x97          ;

; P1 alternate functions - SAB80C515 specific
INT3    = 0x90          ;
CC0     = 0x90          ;
INT4    = 0x91          ;
CC1     = 0x91          ;
INT5    = 0x92          ;
CC2     = 0x92          ;
INT6    = 0x93          ;
CC3     = 0x93          ;
INT2    = 0x94          ;
T2EX    = 0x95          ;
CLKOUT  = 0x96          ;
T2      = 0x97          ;

; SCON
RI      = 0x98          ;
TI      = 0x99          ;
RB8     = 0x9A          ;
TB8     = 0x9B          ;
REN     = 0x9C          ;
SM2     = 0x9D          ;
SM1     = 0x9E          ;
SM0     = 0x9F          ;

; P2
P2.0    = 0xA0          ;
P2.1    = 0xA1          ;
P2.2    = 0xA2          ;
P2.3    = 0xA3          ;
P2.4    = 0xA4          ;
P2.5    = 0xA5          ;
P2.6    = 0xA6          ;
P2.7    = 0xA7          ;

; IE, IEN0
EX0     = 0xA8          ;
ET0     = 0xA9          ;
EX1     = 0xAA          ;
ET1     = 0xAB          ;
ES      = 0xAC          ;
ET2     = 0xAD          ;
WDT     = 0xAE          ; watchdog timer reset - SAB80C517 specific
EA      = 0xAF          ;
EAL     = 0xAF          ; EA as called by Siemens

; P3
P3.0    = 0xB0          ;
P3.1    = 0xB1          ;
P3.2    = 0xB2          ;
P3.3    = 0xB3          ;
P3.4    = 0xB4          ;
P3.5    = 0xB5          ;
P3.6    = 0xB6          ;
P3.7    = 0xB7          ;

RXD     = 0xB0          ;
TXD     = 0xB1          ;
INT0    = 0xB2          ;
INT1    = 0xB3          ;
T0      = 0xB4          ;
T1      = 0xB5          ;
WR      = 0xB6          ;
RD      = 0xB7          ;

; IEN1
EADC    = 0xB8          ; A/D converter interrupt enable
EX2     = 0xB9          ;
EX3     = 0xBA          ;
EX4     = 0xBB          ;
EX5     = 0xBC          ;
EX6     = 0xBD          ;
SWDT    = 0xBE          ; watchdog timer start/reset
EXEN2   = 0xBF          ; timer2 external reload interrupt enable

; IRCON
IADC    = 0xC0          ; A/D converter irq flag
IEX2    = 0xC1          ; external interrupt edge detect flag
IEX3    = 0xC2          ;
IEX4    = 0xC3          ;
IEX5    = 0xC4          ;
IEX6    = 0xC5          ;
TF2     = 0xC6          ; timer 2 owerflow flag 
EXF2    = 0xC7          ; timer 2 reload flag

; T2CON
T2CON.0 = 0xC8          ;
T2CON.1 = 0xC9          ;
T2CON.2 = 0xCA          ;
T2CON.3 = 0xCB          ;
T2CON.4 = 0xCC          ;
T2CON.5 = 0xCD          ;
T2CON.6 = 0xCE          ;
T2CON.7 = 0xCF          ;

T2I0    = 0xC8          ;
T2I1    = 0xC9          ;
T2CM    = 0xCA          ;
T2R0    = 0xCB          ;
T2R1    = 0xCC          ;
I2FR    = 0xCD          ;
I3FR    = 0xCE          ;
T2PS    = 0xCF          ;

; PSW
P       = 0xD0          ;
F1      = 0xD1          ;
FL      = 0xD1          ; andere Bezeichnung F1
OV      = 0xD2          ;
RS0     = 0xD3          ;
RS1     = 0xD4          ;
F0      = 0xD5          ;
AC      = 0xD6          ;
CY      = 0xD7          ;

; ADCON, ADCON0
MX0     = 0xD8          ;
MX1     = 0xD9          ;
MX2     = 0xDA          ;
ADM     = 0xDB          ;
BSY     = 0xDC          ;
ADEX    = 0xDD          ;
CLK     = 0xDE          ;
BD      = 0xDF          ;

; A
A.0     = 0xE0          ;
A.1     = 0xE1          ;
A.2     = 0xE2          ;
A.3     = 0xE3          ;
A.4     = 0xE4          ;
A.5     = 0xE5          ;
A.6     = 0xE6          ;
A.7     = 0xE7          ;
ACC.0   = 0xE0          ;
ACC.1   = 0xE1          ;
ACC.2   = 0xE2          ;
ACC.3   = 0xE3          ;
ACC.4   = 0xE4          ;
ACC.5   = 0xE5          ;
ACC.6   = 0xE6          ;
ACC.7   = 0xE7          ;

; P4
P4.0    = 0xE8          ;
P4.1    = 0xE9          ;
P4.2    = 0xEA          ;
P4.3    = 0xEB          ;
P4.4    = 0xEC          ;
P4.5    = 0xED          ;
P4.6    = 0xEE          ;
P4.7    = 0xEF          ;

; B
B.0     = 0xF0          ;
B.1     = 0xF1          ;
B.2     = 0xF2          ;
B.3     = 0xF3          ;
B.4     = 0xF4          ;
B.5     = 0xF5          ;
B.6     = 0xF6          ;
B.7     = 0xF7          ;
BCC.0   = 0xF0          ;
BCC.1   = 0xF1          ;
BCC.2   = 0xF2          ;
BCC.3   = 0xF3          ;
BCC.4   = 0xF4          ;
BCC.5   = 0xF5          ;
BCC.6   = 0xF6          ;
BCC.7   = 0xF7          ;

; P5
P5.0    = 0xF8          ;
P5.1    = 0xF9          ;
P5.2    = 0xFA          ;
P5.3    = 0xFB          ;
P5.4    = 0xFC          ;
P5.5    = 0xFD          ;
P5.6    = 0xFE          ;
P5.7    = 0xFF          ;

; BIT definitions for bits that are not directly accessible
; PCON bits
IDL     = 0x01
PD      = 0x02
GF0     = 0x04
GF1     = 0x08
SD      = 0x10          ; Slow Down Mode
IDLS    = 0x20          ; Idle Mode Start
PDS     = 0x40          ; Power Down Mode Start
SMOD    = 0x80

; TMOD bits
M0_0    = 0x01
M1_0    = 0x02
C_T0    = 0x04
GATE0   = 0x08
M0_1    = 0x10
M1_1    = 0x20
C_T1    = 0x40
GATE1   = 0x80

T0_M0   = 0x01
T0_M1   = 0x02
T0_CT   = 0x04
T0_GATE = 0x08
T1_M0   = 0x10
T1_M1   = 0x20
T1_CT   = 0x40
T1_GATE = 0x80

T0_MASK = 0x0F
T1_MASK = 0xF0

; Interrupt numbers: address = (number * 8) + 3
IE0_VECTOR  =   0       ; 0x03 external interrupt 0
TF0_VECTOR  =   1       ; 0x0b timer 0
IE1_VECTOR  =   2       ; 0x13 external interrupt 1
TF1_VECTOR  =   3       ; 0x1b timer 1
SI0_VECTOR  =   4       ; 0x23 serial port 0
TF2_VECTOR  =   5       ; 0x2B timer 2
EX2_VECTOR  =   5       ; 0x2B external interrupt 2

IADC_VECTOR =   8       ; 0x43 A/D converter interrupt
IEX2_VECTOR =   9       ; 0x4B external interrupt 2
IEX3_VECTOR =  10       ; 0x53 external interrupt 3
IEX4_VECTOR =  11       ; 0x5B external interrupt 4
IEX5_VECTOR =  12       ; 0x63 external interrupt 5
IEX6_VECTOR =  13       ; 0x6B external interrupt 6


; Bits in nicht bitadressierbaren Registern:

; Bitpositionen in einem Byte:
BIT0    =  (0x01 << 0)
BIT1    =  (0x01 << 1)
BIT2    =  (0x01 << 2)
BIT3    =  (0x01 << 3)
BIT4    =  (0x01 << 4)
BIT5    =  (0x01 << 5)
BIT6    =  (0x01 << 6)
BIT7    =  (0x01 << 7)

; IP0 (A9H):
IP0_0   = BIT0
IP0_1   = BIT1
IP0_2   = BIT2
IP0_3   = BIT3
IP0_4   = BIT4
IP0_5   = BIT5
WDTS    = BIT6
OWDS    = BIT7

; SYSCON (B1H):
XMAP0   = BIT0
XMAP1   = BIT1

; IP1 (B9H):
IP1_0   = BIT0
IP1_1   = BIT1
IP1_2   = BIT2
IP1_3   = BIT3
IP1_4   = BIT4
IP1_5   = BIT5

; CCEN (C1H):
COCAL0  = BIT0
COCAH0  = BIT1
COCAL1  = BIT2
COCAH1  = BIT3
COCAL2  = BIT4
COCAH2  = BIT5
COCAL3  = BIT6
COCAH3  = BIT7

; ADDATL (DAH):
ADDATL_MASK = (BIT7 | BIT6)

; ADCON1 (DCH):
ADCL    = BIT7

;-------------------------------------------------------------------------------
;  END OF FILE
;-------------------------------------------------------------------------------

